#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_TWENTY_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_TWENTY_HPP_INCLUDED

#include <boost/simd/constant/include/constants/twenty.hpp>

#endif
